Validates whether a backend connection has sufficient permissions for {dsROCrate} audit operations.

check_permissions(x, ...)

# S3 method for class 'ArmadilloCredentials'
check_permissions(x, ...)

# S3 method for class 'opal'
check_permissions(x, ..., verbose = FALSE)

Arguments

x

A backend connection object.

...

Additional arguments passed to methods.

verbose

Boolean value used to indicate if a success message should be displayed (default: FALSE)

Value

Returns TRUE invisibly if the connection has sufficient permissions.

Details

Currently, audit or administrator permissions are required.