Create an audit RO-Crate following the 5 Safes Principles.
audit(x, ...)
# S3 method for class 'ArmadilloCredentials'
audit(x, ..., intent = NULL)
# S3 method for class 'character'
audit(x, ..., intent = NULL)
# S3 method for class 'cr8tor'
audit(x, ..., intent = NULL)
# S3 method for class 'list'
audit(x, ..., intent = NULL)
# S3 method for class 'opal'
audit(
x,
...,
intent = NULL,
project = NULL,
user = NULL,
logs_from = -Inf,
logs_to = Inf,
path = NULL
)
# S3 method for class 'rocrate'
audit(x, ..., intent = NULL)Object to be audited. This can be
a connection to a DataSHIELD server (e.g., OBiBa's Opal).
a path pointing to an RO-Crate OR a cr8tor archive /
. governance bundle.
an RO-Crate object.
Alternatively, a list of any of the above.
Additional arguments.
Additional object with governance bundle/specification of the
intent of a project. It takes the same types as x.
String with project name(s) from which to extra Safe Project details.
String with the user name for which to extract Safe People details.
Lower limit timestamp to filter out the outputs generated
(default: -Inf, everything up to logs_to)
Upper limit timestamp to filter out the outputs generated
(default: Inf, everything from logs_from onwards).
String with path pointing to the root of the RO-Crate. This will be used to store log files. If not provided, logs will be stored within the RO-Crate returned by this function.
RO-Crate with audit details.
This function handles various audit types, which will be dispatched based on the input object. If the input object is
a connection to a DataSHIELD server (e.g., OBiBa's Opal): . generates an RO-Crate object with deployment details, including outputs.
a path pointing to
a cr8tor archive / governance bundle: generates an
RO-Crate object with pre-deployment governance details.
an RO-Crate object: generates an RO-Crate object with clearly defined 5 Safes elements.
an RO-Crate object: generates an RO-Crate object with clearly defined 5 Safes elements.