Create an RO-Crate report
report(x, ...)
# S3 method for class 'character'
report(
x,
...,
title = "DataSHIELD Report",
filepath = tempfile(fileext = ".md"),
render = TRUE,
doc_format = "html",
overwrite = FALSE,
include_user_perm = TRUE,
diag_title = "DataSHIELD server",
diag_width = NULL,
diag_height = NULL,
max_line_length = 200
)
# Default S3 method
report(x, ...)
# S3 method for class 'list'
report(
x,
...,
study_name,
title = "DataSHIELD Report",
filepath = tempfile(fileext = ".md"),
render = TRUE,
doc_format = "html",
overwrite = FALSE,
include_user_perm = TRUE,
diag_title = "DataSHIELD server",
diag_width = NULL,
diag_height = NULL,
max_line_length = 200
)
# S3 method for class 'rocrate'
report(
x,
...,
title = "DataSHIELD Report",
filepath = tempfile(fileext = ".md"),
render = TRUE,
doc_format = "html",
overwrite = FALSE,
include_user_perm = TRUE,
diag_title = "DataSHIELD server",
diag_width = NULL,
diag_height = NULL,
max_line_length = 200
)This can be an RO-Crate (rocrate class) or a string with the path to an RO-Crate.
Other optional arguments. See the full documentation,
?dsROCrate::report.
String with title for the report (default: 'DataSHIELD Report').
String with file path for Markdown report with the summary
of the given object, x.
Boolean flag to indicate whether to render the markdown report.
String with file format for the markdown report.
Boolean flag to indicate whether to overwrite a previous version of markdown report.
Boolean flag to indicate whether to include user permissions in the report overview's diagram.
String with title for the 'root' of the diagram (default: 'DataSHIELD server').
Numeric value with width (in inches) for the report
overview's diagram (default: NULL, estimated based on number of nodes).
Numeric value with height (in inches) for the report
overview's diagram (default: NULL, estimated based on number of nodes).
Integer with the maximum number of characters per line in the RO-Crate to be printed in the report.
String with the study name.
RO-Crate report as markdown (.md) file and/or HTML.