Safe Output details for the RO-Crate.
safe_output(x, ...)
# S3 method for class 'character'
safe_output(
x,
...,
path = attr(x, "path"),
user = attr(x, "user"),
logs_to = Sys.time(),
logs_from = logs_to - 24 * 60^2,
connection = attr(x, "connection"),
profile = attr(x, "profile"),
project = attr(x, "project"),
resources = attr(x, "resources"),
tables = attr(x, "tables")
)
# S3 method for class 'opal'
safe_output(
x,
...,
rocrate = rocrateR::rocrate_5s(),
path = NULL,
user = NULL,
logs_to = Sys.time(),
logs_from = logs_to - 24 * 60^2,
profile = "default",
project = NULL,
resources = NULL,
tables = NULL
)
# S3 method for class 'rocrate'
safe_output(
x,
...,
path = attr(x, "path"),
user = attr(x, "user"),
logs_to = Sys.time(),
logs_from = logs_to - 24 * 60^2,
connection = attr(x, "connection"),
profile = attr(x, "profile"),
project = attr(x, "project"),
resources = attr(x, "resources"),
tables = attr(x, "tables")
)Research Data Scotland, 2025. "What is the Five Safes framework?". https://www.researchdata.scot/engage-and-learn/data-explainers/what-is-the-five-safes-framework/
This can be a connection to a 'DataSHIELD' server (e.g., object with
the opal class, see opalr::opal.login()), an RO-Crate
(rocrate class) or a string with the path to an
RO-Crate.
Other optional arguments. See the full documentation,
?dsROCrate::safe_output.
String with path pointing to the root of the RO-Crate. This will be used to store log files. If not provided, logs will be stored within the RO-Crate returned by this function.
List (or entity object) with details for
the Safe People, it must include @id and name entries. Alternatively,
this can be a string with the name of the current user.
Upper limit timestamp to filter out the outputs generated
(default: Sys.time(), current system time).
Lower limit timestamp to filter out the outputs generated
(default: Sys.time() - 24 * 60 ^ 2, last 24 hours).
Connection object for the 'DataSHIELD' server where the
values will be extracted from (e.g., OBiBa's Opal). Optional, if x is
set to a connection object. If so, then rocrate is required.
String with profile name (used for OBiBa's Opal backend).
String with the name of the Safe Project.
Vector of strings with the names of the resources, part of
project. Optional, if not provided, all the resources associated to
project will be included in the RO-Crate.
Vector of strings with the names of the tables/datasets, part
of project. Optional, if not provided, all the tables/datasets
associated to project will be included in the RO-Crate.
RO-Crate object. Optional, if x is either an RO-Crate
object or a path to a valid RO-Crate. If so, then connection is
required (default: rocrateR::rocrate_5s()).
Updated RO-Crate object with Safe Outputs information.
All research outputs are checked to ensure individuals cannot be identified even in the public domain.
This means the other four Safes no longer apply.
Before outputs are released from the TRE, they are checked to make sure it is reasonably unlikely that any individuals can be identified on publication. Compliance with the Digital Economy Act also requires that the TRE applies methods and standards for output checking that are accredited by the UK Statistics Authority.