Safe People details for the RO-Crate.
safe_people(x, ...)
# S3 method for class 'character'
safe_people(
x,
...,
user = attr(x, "user"),
user_id_suffix = "#person:",
set_author = TRUE,
set_project = TRUE,
connection = attr(x, "connection"),
path = attr(x, "path"),
profile = attr(x, "profile"),
project = attr(x, "project"),
resources = attr(x, "resources"),
tables = attr(x, "tables")
)
# S3 method for class 'opal'
safe_people(
x,
...,
rocrate = rocrateR::rocrate_5s(),
user = NULL,
user_id_suffix = "#person:",
set_author = TRUE,
set_project = TRUE,
path = NULL,
profile = "default",
project = NULL,
resources = NULL,
tables = NULL
)
# S3 method for class 'rocrate'
safe_people(
x,
...,
user = attr(x, "user"),
user_id_suffix = "#person:",
set_author = TRUE,
set_project = TRUE,
connection = attr(x, "connection"),
path = attr(x, "path"),
profile = attr(x, "profile"),
project = attr(x, "project"),
resources = attr(x, "resources"),
tables = attr(x, "tables")
)Research Data Scotland, 2025. "What is the Five Safes framework?". https://www.researchdata.scot/engage-and-learn/data-explainers/what-is-the-five-safes-framework/
This can be a connection to a 'DataSHIELD' server (e.g., object with
the opal class, see opalr::opal.login()), an RO-Crate
(rocrate class) or a string with the path to an
RO-Crate.
Other optional arguments. See the full documentation,
?dsROCrate::safe_people.
List (or entity object) with details for
the Safe People, it must include @id and name entries. Alternatively,
this can be a string with the name of the current user.
String with ID suffix for the tables/datasets
entities in the RO-Crate (default: "#dataset:").
Boolean flag to indicate if the current user should be set as the author of the RO-Crate.
Boolean flag to indicate if any Project entities found
in x should be linked to the Safe People entity.
Connection object for the 'DataSHIELD' server where the
values will be extracted from (e.g., OBiBa's Opal). Optional, if x is
set to a connection object. If so, then rocrate is required.
String with path pointing to the root of the RO-Crate. This will be used to store log files. If not provided, logs will be stored within the RO-Crate returned by this function.
String with profile name (used for OBiBa's Opal backend).
String with the name of the Safe Project.
Vector of strings with the names of the resources, part of
project. Optional, if not provided, all the resources associated to
project will be included in the RO-Crate.
Vector of strings with the names of the tables/datasets, part
of project. Optional, if not provided, all the tables/datasets
associated to project will be included in the RO-Crate.
RO-Crate object. Optional, if x is either an RO-Crate
object or a path to a valid RO-Crate. If so, then connection is
required (default: rocrateR::rocrate_5s()).
Updated RO-Crate object with Safe People information.
Researchers must be accredited and trained before accessing the data that has been prepared for them.
The access service provider may require the researcher to sign a statement that they know and understand the regulations of the TRE.