Safe Setting details for the RO-Crate.
safe_setting(x, ...)
# S3 method for class 'character'
safe_setting(
x,
...,
connection = attr(x, "connection"),
path = attr(x, "path"),
profile = attr(x, "profile"),
project = attr(x, "project"),
tables = attr(x, "tables"),
resources = attr(x, "resources"),
user = attr(x, "user")
)
# S3 method for class 'cr8tor'
safe_setting(x, ..., rocrate = rocrateR::rocrate_5s())
# S3 method for class 'opal'
safe_setting(
x,
...,
rocrate = rocrateR::rocrate_5s(),
path = NULL,
profile = "default",
project = NULL,
resources = NULL,
tables = NULL,
user = NULL
)
# S3 method for class 'rocrate'
safe_setting(
x,
...,
connection = attr(x, "connection"),
path = attr(x, "path"),
profile = attr(x, "profile"),
project = attr(x, "project"),
resources = attr(x, "resources"),
tables = attr(x, "tables"),
user = attr(x, "user")
)Research Data Scotland, 2025. "What is the Five Safes framework?". https://www.researchdata.scot/engage-and-learn/data-explainers/what-is-the-five-safes-framework/
This can be a connection to a 'DataSHIELD' server (e.g., object with
the opal class, see opalr::opal.login()), an RO-Crate
(rocrate class) or a string with the path to an
RO-Crate.
Other optional arguments. See the full documentation,
?dsROCrate::safe_setting.
Connection object for the 'DataSHIELD' server where the
values will be extracted from (e.g., OBiBa's Opal). Optional, if x is
set to a connection object. If so, then rocrate is required.
String with path pointing to the root of the RO-Crate. This will be used to store log files. If not provided, logs will be stored within the RO-Crate returned by this function.
String with profile name (used for OBiBa's Opal backend).
String with the name of the Safe Project.
Vector of strings with the names of the tables/datasets, part
of project. Optional, if not provided, all the tables/datasets
associated to project will be included in the RO-Crate.
Vector of strings with the names of the resources, part of
project. Optional, if not provided, all the resources associated to
project will be included in the RO-Crate.
List (or entity object) with details for
the Safe People, it must include @id and name entries. Alternatively,
this can be a string with the name of the current user.
RO-Crate object. Optional, if x is either an RO-Crate
object or a path to a valid RO-Crate. If so, then connection is
required (default: rocrateR::rocrate_5s()).
Updated RO-Crate object with Safe Settings information.
The organisational and technical settings used to access data are designed to minimise the risk of accidental disclosure of data.
These settings also prevent the deliberate disclosure of data to others.
Physical settings for data access can include locations like SafePods – secured rooms that use controlled door access, CCTV and secure technology to ensure that sensitive data cannot be mishandled or removed from the Safe Setting. Researchers can analyse the data in these secure rooms, but do not have access to the internet, external devices (such as printers), or any other way of removing protected data from the space.
Digital Safe Settings provide secure access to data from a remote location. To be approved for remote data access, researchers will need to prove that their organisation meets physical and IT security standards.